@@ -15,8 +15,11 @@
 import os
 import time
 
+from .nrunner import TASK_DEFAULT_CATEGORY
 from .test_id import TestID
 
+DEFAULT_LOG_FILE = 'debug.log'
+
 
 class BaseMessageHandler:
     """
@@ -99,15 +102,18 @@ class StartMessageHandler(BaseMessageHandler):
         task_id = TestID.from_identifier(task.identifier)
         base_path = job.test_results_path
         task_path = os.path.join(base_path, task_id.str_filesystem)
+        logfile = os.path.join(task_path, DEFAULT_LOG_FILE)
         os.makedirs(task_path, exist_ok=True)
+        open(logfile, 'w').close()
         metadata = {'job_logdir': job.logdir,
                     'job_unique_id': job.unique_id,
                     'base_path': base_path,
+                    'logfile':  logfile,
                     'task_path': task_path,
                     'time_start': message['time'],
                     'actual_time_start': time.time(),
                     'name': task_id}
-        if task.category == 'test':
+        if task.category == TASK_DEFAULT_CATEGORY:
             job.result.start_test(metadata)
             job.result_events_dispatcher.map_method('start_test', job.result,
                                                     metadata)
@@ -157,6 +163,59 @@ class FinishMessageHandler(BaseMessageHandler):
 class BaseRunningMessageHandler(BaseMessageHandler):
     """Base interface for resolving running messages."""
 
+    _tag = b''
+
+    def __init__(self):
+        self.line_buffer = b''
+
+    def _split_complete_lines(self, data):
+        """
+        It will split data into list of lines.
+
+        If the data don't finish with the new line character, the last line is
+        marked as incomplete, and it is saved to the line buffer for next usage.
+
+        When the buffer is not empty the buffer will be added at the beginning
+        of data.
+
+        :param data: massage log
+        :type data: bytes
+        :return: list of lines
+        """
+        data_lines = data.splitlines(True)
+        if len(data_lines) <= 1 and not data.endswith(b'\n'):
+            self.line_buffer += data
+            return []
+        else:
+            data_lines[0] = self.line_buffer + data_lines[0]
+            self.line_buffer = b''
+            if not data.endswith(b'\n'):
+                self.line_buffer = data_lines.pop()
+            return data_lines
+
+    def _save_to_default_file(self, message, task):
+        """
+        It will save message log into the default log file.
+
+        The default log file is based on `DEFAULT_LOG_FILE` variable and every
+        line of log will be saved with prefix based on `_tag` variable
+
+        :param message: message from runner
+        :type message: dict
+        :param task: runtime_task which message is related to
+        :type task: :class:`avocado.core.nrunner.Task`
+        """
+
+        if message.get('encoding'):
+            data = message.get('log', b'').splitlines(True)
+        else:
+            data = self._split_complete_lines(message.get('log', b''))
+
+        if data:
+            data = self._tag + self._tag.join(data)
+            self._save_message_to_file(DEFAULT_LOG_FILE, data, task,
+                                       message.get('encoding'))
+
     @staticmethod
     def _message_to_line(message, encoding):
         """
@@ -225,6 +284,8 @@ class LogMessageHandler(BaseRunningMessageHandler):
              'time': 18405.55351474}
     """
 
+    _tag = b'[debug] '
+
     def handle(self, message, task, job):
         """Logs a textual message to a file.
 
@@ -234,15 +295,14 @@ class LogMessageHandler(BaseRunningMessageHandler):
         if task.metadata.get('logfile') is None:
             task.metadata['logfile'] = os.path.join(task.metadata['task_path'],
                                                     'debug.log')
-        self._save_message_to_file('debug.log', message['log'], task,
-                                   message.get('encoding', None))
+        self._save_to_default_file(message, task)
 
 
 class StdoutMessageHandler(BaseRunningMessageHandler):
     """
     Handler for stdout message.
 
-    It will save the stdout to the stdout file in the task directory.
+    It will save the stdout to the stdout and debug file in the task directory.
 
     :param status: 'running'
     :param type: 'stdout'
@@ -257,7 +317,10 @@ class StdoutMessageHandler(BaseRunningMessageHandler):
              'time': 18405.55351474}
     """
 
+    _tag = b'[stdout] '
+
     def handle(self, message, task, job):
+        self._save_to_default_file(message, task)
         self._save_message_to_file('stdout', message['log'], task,
                                    message.get('encoding', None))
 
@@ -266,7 +329,7 @@ class StderrMessageHandler(BaseRunningMessageHandler):
     """
     Handler for stderr message.
 
-    It will save the stderr to the stderr file in the task directory.
+    It will save the stderr to the stderr and debug file in the task directory.
 
     :param status: 'running'
     :param type: 'stderr'
@@ -281,7 +344,10 @@ class StderrMessageHandler(BaseRunningMessageHandler):
              'time': 18405.55351474}
     """
 
+    _tag = b'[stderr] '
+
     def handle(self, message, task, job):
+        self._save_to_default_file(message, task)
         self._save_message_to_file('stderr', message['log'], task,
                                    message.get('encoding', None))
 
@@ -344,6 +410,6 @@ class FileMessageHandler(BaseRunningMessageHandler):
         filename = os.path.relpath(os.path.join("/", message['path']), "/")
         file = os.path.join(task.metadata['task_path'], filename)
         if not os.path.exists(file):
-            os.makedirs(os.path.dirname(file))
+            os.makedirs(os.path.dirname(file), exist_ok=True)
         self._save_message_to_file(filename, message['log'], task,
                                    message.get('encoding', None))
