@@ -15,7 +15,7 @@ import subprocess
 import sys
 import tempfile
 import time
-import unittest
+from unittest import TestLoader, TextTestRunner
 from uuid import uuid1
 
 try:
@@ -42,6 +42,10 @@ RUNNERS_REGISTRY_STANDALONE_EXECUTABLE = {}
 #: SpawnMethod.PYTHON_CLASS
 RUNNERS_REGISTRY_PYTHON_CLASS = {}
 
+#: The default category for tasks, and the value that will cause the
+#: task results to be included in the job results
+TASK_DEFAULT_CATEGORY = 'test'
+
 
 def check_runnables_runner_requirements(runnables, runners_registry=None):
     """
@@ -116,13 +120,15 @@ class Runnable:
         self.args = args
         self.tags = kwargs.pop('tags', None)
         self.requirements = kwargs.pop('requirements', None)
+        self.variant = kwargs.pop('variant', None)
         self.kwargs = kwargs
 
     def __repr__(self):
         fmt = ('<Runnable kind="{}" uri="{}" config="{}" args="{}" '
-               'kwargs="{}" tags="{}" requirements="{}">')
+               'kwargs="{}" tags="{}" requirements="{}"> variant="{}"')
         return fmt.format(self.kind, self.uri, self.config, self.args,
-                          self.kwargs, self.tags, self.requirements)
+                          self.kwargs, self.tags, self.requirements,
+                          self.variant)
 
     @classmethod
     def from_args(cls, args):
@@ -181,6 +187,9 @@ class Runnable:
         if self.tags is not None:
             args.append('tags=json:%s' % json.dumps(self.get_serializable_tags()))
 
+        if self.variant is not None:
+            args.append('variant=json:%s' % json.dumps(self.variant))
+
         for key, val in self.kwargs.items():
             if not isinstance(val, str) or isinstance(val, int):
                 val = "json:%s" % json.dumps(val)
@@ -206,6 +215,8 @@ class Runnable:
         kwargs = self.kwargs.copy()
         if self.tags is not None:
             kwargs['tags'] = self.get_serializable_tags()
+        if self.variant is not None:
+            kwargs['variant'] = self.variant
         if kwargs:
             recipe['kwargs'] = kwargs
         return recipe
@@ -445,6 +456,21 @@ class ExecRunner(BaseRunner):
         return self.prepare_status('finished',
                                    {'returncode': process.returncode})
 
+    def _create_params(self):
+        """Create params for the test"""
+        # inject the -p command-line / run.test_parameters option in the
+        # environment variables
+        params = dict(self.runnable.config.get('run.test_parameters', []))
+
+        if self.runnable.variant is not None:
+            params_from_variant = dict([(str(key), str(val)) for _, key, val in
+                                        self.runnable.variant['variant'][0][1]])
+            # if we have params from the variant, replace the original params
+            if params_from_variant:
+                params = params_from_variant
+
+        return params
+
     def run(self):
         env = None
         if self.runnable.kwargs:
@@ -452,9 +478,7 @@ class ExecRunner(BaseRunner):
             current.update(self.runnable.kwargs)
             env = current
 
-        # inject the run.test_parameters option in the environment variables
-        # this handles the -p command-line argument
-        params = dict(self.runnable.config.get('run.test_parameters', []))
+        params = self._create_params()
         if params:
             env.update(params)
 
@@ -542,23 +566,23 @@ class PythonUnittestRunner(BaseRunner):
 
     Runnable attributes usage:
 
-     * uri: a "dotted name" that can be given to Python standard
-            library's :meth:`unittest.TestLoader.loadTestsFromName`
-            method. While it's not enforced, it's highly recommended
-            that this is "a test method within a test case class" within
-            a test module.  Example is: "module.Class.test_method".
+     * uri: a single test reference, that is "a test method within a test case
+            class" within a test module.  Example is:
+            "./tests/foo.py:ClassFoo.test_bar".
 
      * args: not used
 
      * kwargs: not used
     """
-    @staticmethod
-    def _uri_to_unittest_name(uri):
+
+    @property
+    def unittest(self):
+        uri = self.runnable.uri
         if ':' in uri:
             module, class_method = uri.rsplit(':', 1)
         else:
-            module = uri
-            class_method = None
+            return None
+
         if module.endswith('.py'):
             module = module[:-3]
         if module.startswith(os.path.curdir):
@@ -566,17 +590,61 @@ class PythonUnittestRunner(BaseRunner):
             if module.startswith(os.path.sep):
                 module = module[1:]
         module = module.replace(os.path.sep, ".")
-        if class_method:
-            return '%s.%s' % (module, class_method)
-        return module
+        klass, method = class_method.rsplit('.', maxsplit=1)
+        return module, klass, method
 
-    @staticmethod
-    def _run_unittest(uri, queue):
-        sys.path.insert(0, ".")
+    @property
+    def unittest_name(self):
+        """Convert a test reference (uri) to an unittest name reference."""
+        unittest = self.unittest
+        if not unittest:
+            return None
+        return "{}.{}.{}".format(*unittest)
+
+    @property
+    def module_path(self):
+        unittest = self.unittest
+        if not unittest:
+            return None
+        module, _, _ = unittest
+        path = module.replace('.', os.path.sep)
+        # This will fix adding support to hidden directories
+        path = path.replace('//', '/.')
+        return os.path.dirname(path)
+
+    @property
+    def module_class_method(self):
+        """Return a dotted name with module + class + method.
+
+        Important to note here that module is only the module file without the
+        full path.
+        """
+        unittest = self.unittest
+        if not unittest:
+            return None
+
+        full_module, klass, method = unittest
+        # Lets split the full_module and get the module_path + module it self
+        # We care here only about the module (without the path)
+        _, module = full_module.rsplit(".", maxsplit=1)
+        return ".".join((module, klass, method))
+
+    @classmethod
+    def _run_unittest(cls, module_path, module_class_method, queue):
+        sys.path.insert(0, module_path)
         stream = io.StringIO()
-        unittest_name = PythonUnittestRunner._uri_to_unittest_name(uri)
-        suite = unittest.TestLoader().loadTestsFromName(unittest_name)
-        runner = unittest.TextTestRunner(stream=stream, verbosity=0)
+
+        try:
+            loader = TestLoader()
+            suite = loader.loadTestsFromName(module_class_method)
+        except ValueError as ex:
+            msg = "loadTestsFromName error finding unittest {}: {}"
+            queue.put({'status': 'finished',
+                       'result': 'error',
+                       'output': msg.format(module_class_method, str(ex))})
+            return
+
+        runner = TextTestRunner(stream=stream, verbosity=0)
         unittest_result = runner.run(suite)
 
         if len(unittest_result.errors) > 0:
@@ -596,15 +664,18 @@ class PythonUnittestRunner(BaseRunner):
         queue.put(output)
 
     def run(self):
-        if not self.runnable.uri:
-            error_msg = 'uri is required but was not given'
+        if not self.unittest_name:
+            error_msg = ("Invalid URI: could not be converted to an unittest "
+                         "dotted name.")
             yield self.prepare_status('finished', {'result': 'error',
                                                    'output': error_msg})
             return
 
         queue = multiprocessing.SimpleQueue()
         process = multiprocessing.Process(target=self._run_unittest,
-                                          args=(self.runnable.uri, queue))
+                                          args=(self.module_path,
+                                                self.module_class_method,
+                                                queue))
         process.start()
         yield self.prepare_status('started')
 
@@ -703,10 +774,16 @@ class TaskStatusService:
         self.connection = None
 
     def post(self, status):
-        host, port = self.uri.split(':')
-        port = int(port)
-        if self.connection is None:
-            self.connection = socket.create_connection((host, port))
+        if ':' in self.uri:
+            host, port = self.uri.split(':')
+            port = int(port)
+            if self.connection is None:
+                self.connection = socket.create_connection((host, port))
+        else:
+            if self.connection is None:
+                self.connection = socket.socket(socket.AF_UNIX,
+                                                socket.SOCK_STREAM)
+                self.connection.connect(self.uri)
 
         data = json_dumps(status)
         self.connection.send(data.encode('ascii') + "\n".encode('ascii'))
@@ -729,7 +806,8 @@ class Task:
     """
 
     def __init__(self, runnable, identifier=None, status_uris=None,
-                 known_runners=None, category='test'):
+                 known_runners=None, category=TASK_DEFAULT_CATEGORY,
+                 job_id=None):
         """Instantiates a new Task.
 
         :param runnable: the "description" of what the task should run.
@@ -746,14 +824,20 @@ class Task:
         :type status_uri: list
         :param known_runners: a mapping of runnable kinds to runners.
         :type known_runners: dict
-        :param category: category of this task. Defaults to 'test'.
+        :param category: category of this task. Defaults to
+                         :data:`TASK_DEFAULT_CATEGORY`.
         :type category: str
+        :param job_id: the ID of the job, for authenticating messages that get
+                       sent to the destination job's status server and will make
+                       into the job's results.
+        :type job_id: str
         """
         self.runnable = runnable
         self.identifier = identifier or str(uuid1())
         #: Category of the task.  If the category is not "test", it
         #: will not be accounted for on a Job's test results.
         self.category = category
+        self.job_id = job_id
         self.status_services = []
         status_uris = status_uris or self.runnable.config.get('nrunner.status_server_uri')
         if status_uris is not None:
@@ -771,9 +855,9 @@ class Task:
 
     def __repr__(self):
         fmt = ('<Task identifier="{}" runnable="{}" dependencies="{}"'
-               ' status_services="{}"')
+               ' status_services="{}" category="{}" job_id="{}">')
         return fmt.format(self.identifier, self.runnable, self.dependencies,
-                          self.status_services)
+                          self.status_services, self.category, self.job_id)
 
     def are_requirements_available(self, runners_registry=None):
         """Verifies if requirements needed to run this task are available.
@@ -788,7 +872,7 @@ class Task:
 
     def setup_output_dir(self):
         self.output_dir = tempfile.mkdtemp(prefix='.avocado-task-')
-        env_var = {'AVOCADO_TEST_OUTPUT_DIR': self.output_dir}
+        env_var = {'AVOCADO_TEST_OUTPUTDIR': self.output_dir}
         self.runnable.kwargs.update(env_var)
 
     @classmethod
@@ -811,7 +895,9 @@ class Task:
                             *runnable_recipe.get('args', ()),
                             config=runnable_recipe.get('config'))
         status_uris = recipe.get('status_uris')
-        return cls(runnable, identifier, status_uris, known_runners)
+        category = recipe.get('category')
+        return cls(runnable, identifier, status_uris, known_runners,
+                   category)
 
     def get_command_args(self):
         """
@@ -823,7 +909,7 @@ class Task:
         :returns: the arguments that can be used on an avocado-runner command
         :rtype: list
         """
-        args = ['-i', str(self.identifier)]
+        args = ['-i', str(self.identifier), '-j', str(self.job_id)]
         args += self.runnable.get_command_args()
 
         for status_service in self.status_services:
@@ -840,6 +926,8 @@ class Task:
             if status['status'] == 'started':
                 status.update({'output_dir': self.output_dir})
             status.update({"id": self.identifier})
+            if self.job_id is not None:
+                status.update({"job_id": self.job_id})
             for status_service in self.status_services:
                 status_service.post(status)
             yield status
@@ -904,9 +992,20 @@ class BaseRunnerApp:
     CMD_TASK_RUN_ARGS = (
         (('-i', '--identifier'),
          {'type': str, 'required': True, 'help': 'Task unique identifier'}),
+        (('-t', '--category'),
+         {'type': str, 'required': False, 'default': TASK_DEFAULT_CATEGORY,
+          'help': ('The category for tasks. Only tasks with category set '
+                   'to "%s" (the default) will be included in the '
+                   'test results of its parent job. Other categories '
+                   'may be used for purposes that do include test results '
+                   'such as requirements resolution tasks'
+                   % TASK_DEFAULT_CATEGORY)}),
         (('-s', '--status-uri'),
          {'action': 'append', 'default': None,
           'help': 'URIs of status services to report to'}),
+        (('-j', '--job-id'),
+         {'type': str, 'required': False, 'metavar': 'JOB_ID',
+          'help': 'Identifier of Job this task belongs to'}),
     )
     CMD_TASK_RUN_ARGS += CMD_RUNNABLE_RUN_ARGS
 
@@ -1056,7 +1155,9 @@ class BaseRunnerApp:
         runnable = Runnable.from_args(args)
         task = Task(runnable, args.get('identifier'),
                     args.get('status_uri', []),
-                    known_runners=self.RUNNABLE_KINDS_CAPABLE)
+                    known_runners=self.RUNNABLE_KINDS_CAPABLE,
+                    category=args.get('category', TASK_DEFAULT_CATEGORY),
+                    job_id=args.get('job_id'))
         for status in task.run():
             self.echo(status)
 
