@@ -103,11 +103,12 @@ class Run(CLICmd):
                     'installed and active implementations.  You can run '
                     '"avocado plugins" and find the list of valid runners '
                     'under the "Plugins that run test suites on a job '
-                    '(runners) section.  Defaults to "runner", which is '
-                    'the conventional and traditional runner.')
+                    '(runners) section.  Defaults to "nrunner", which is '
+                    'the new runner.  To use the conventional and traditional '
+                    'runner, use "runner".')
         settings.register_option(section='run',
                                  key='test_runner',
-                                 default='runner',
+                                 default='nrunner',
                                  help_msg=help_msg,
                                  parser=parser,
                                  long_arg='--test-runner',
@@ -215,7 +216,8 @@ class Run(CLICmd):
         settings.add_argparser_to_option('job.run.store_logging_stream',
                                          parser=parser.output,
                                          long_arg='--store-logging-stream',
-                                         metavar='LOGGING_STREAM')
+                                         metavar='LOGGING_STREAM',
+                                         argparse_type=lambda x: set(x.split(',')))
 
         help_msg = ('Logs the possible data directories for each test. This '
                     'is helpful when writing new tests and not being sure '
