@@ -18,11 +18,16 @@ NRunner based implementation of job compliant runner
 
 import asyncio
 import multiprocessing
+import os
+import platform
 import random
+from copy import deepcopy
 
 from avocado.core import nrunner
 from avocado.core.dispatcher import SpawnerDispatcher
+from avocado.core.exceptions import JobError, TestFailFast
 from avocado.core.messages import MessageHandler
+from avocado.core.output import LOG_JOB
 from avocado.core.plugin_interfaces import CLI, Init
 from avocado.core.plugin_interfaces import Runner as RunnerInterface
 from avocado.core.requirements.resolver import RequirementsResolver
@@ -32,6 +37,7 @@ from avocado.core.status.server import StatusServer
 from avocado.core.task.runtime import RuntimeTask
 from avocado.core.task.statemachine import TaskStateMachine, Worker
 from avocado.core.test_id import TestID
+from avocado.core.varianter import dump_variant
 
 
 class RunnerInit(Init):
@@ -48,6 +54,16 @@ class RunnerInit(Init):
                                  help_msg=help_msg,
                                  key_type=bool)
 
+        help_msg = ('If the status server should automatically choose '
+                    'a "status_server_listen" and "status_server_uri" '
+                    'configuration. Default is to auto configure a '
+                    'status server.')
+        settings.register_option(section=section,
+                                 key='status_server_auto',
+                                 default=True,
+                                 key_type=bool,
+                                 help_msg=help_msg)
+
         help_msg = ('URI for listing the status server. Usually '
                     'a "HOST:PORT" string')
         settings.register_option(section=section,
@@ -67,7 +83,7 @@ class RunnerInit(Init):
 
         help_msg = ('Buffer size that status server uses.  This should '
                     'generally not be a concern to most users, but '
-                    'it can be tunned in case a runner generates very large '
+                    'it can be tuned in case a runner generates very large '
                     'status messages, which is common if a test generates a '
                     'lot of output. Default is 33554432 (32MiB)')
         settings.register_option(section=section,
@@ -117,6 +133,12 @@ class RunnerCLI(CLI):
                                          long_arg='--nrunner-shuffle',
                                          action='store_true')
 
+        settings.add_argparser_to_option(
+            namespace='nrunner.status_server_auto',
+            parser=parser,
+            long_arg='--nrunner-status-server-disable-auto',
+            action='store_false')
+
         settings.add_argparser_to_option(
             namespace='nrunner.status_server_listen',
             parser=parser,
@@ -150,8 +172,7 @@ class Runner(RunnerInterface):
     name = 'nrunner'
     description = 'nrunner based implementation of job compliant runner'
 
-    @staticmethod
-    def _get_requirements_runtime_tasks(runnable, prefix):
+    def _get_requirements_runtime_tasks(self, runnable, prefix, job_id):
         if runnable.requirements is None:
             return
 
@@ -173,7 +194,9 @@ class Runner(RunnerInterface):
             # creates the requirement task
             requirement_task = nrunner.Task(requirement_runnable,
                                             identifier=task_id,
-                                            category='requirement')
+                                            status_uris=[self.status_server.uri],
+                                            category='requirement',
+                                            job_id=job_id)
             # make sure we track the dependencies of a task
             # runtime_task.task.dependencies.add(requirement_task)
             # created the requirement runtime task
@@ -181,12 +204,13 @@ class Runner(RunnerInterface):
 
         return requirements_runtime_tasks
 
-    @staticmethod
-    def _create_runtime_tasks_for_test(test_suite, runnable, no_digits,
-                                       index, variant):
+    def _create_runtime_tasks_for_test(self, test_suite, runnable, no_digits,
+                                       index, variant, job_id):
         """Creates runtime tasks for both tests, and for its requirements."""
         result = []
+
         # test related operations
+        # create test ID
         if test_suite.name:
             prefix = "{}-{}".format(test_suite.name, index)
         else:
@@ -195,17 +219,23 @@ class Runner(RunnerInterface):
                          runnable.uri,
                          variant,
                          no_digits)
+        # inject variant on runnable
+        runnable.variant = dump_variant(variant)
+
         # handles the test task
         task = nrunner.Task(runnable,
                             identifier=test_id,
-                            known_runners=nrunner.RUNNERS_REGISTRY_PYTHON_CLASS)
+                            known_runners=nrunner.RUNNERS_REGISTRY_PYTHON_CLASS,
+                            status_uris=[self.status_server.uri],
+                            job_id=job_id)
         runtime_task = RuntimeTask(task)
         result.append(runtime_task)
 
         # handles the requirements
         requirements_runtime_tasks = (
-            Runner._get_requirements_runtime_tasks(runnable,
-                                                   prefix))
+            self._get_requirements_runtime_tasks(runnable,
+                                                 prefix,
+                                                 job_id))
         # extend the list of tasks with the requirements runtime tasks
         if requirements_runtime_tasks is not None:
             for requirement_runtime_task in requirements_runtime_tasks:
@@ -216,43 +246,50 @@ class Runner(RunnerInterface):
 
         return result
 
-    @staticmethod
-    def _get_all_runtime_tasks(test_suite):
+    def _get_all_runtime_tasks(self, test_suite, job_id):
         runtime_tasks = []
         test_result_total = test_suite.variants.get_number_of_tests(test_suite.tests)
         no_digits = len(str(test_result_total))
+        # define execution order
         execution_order = test_suite.config.get('run.execution_order')
         if execution_order == "variants-per-test":
-            for index, (runnable, variant) in enumerate(((test, variant)
-                                                         for test in test_suite.tests
-                                                         for variant in test_suite.variants.itertests()),
-                                                        start=1):
-                runtime_tasks.extend(Runner._create_runtime_tasks_for_test(
-                    test_suite,
-                    runnable,
-                    no_digits,
-                    index,
-                    variant))
+            test_variant = [(test, variant) for test in test_suite.tests
+                            for variant in test_suite.variants.itertests()]
         elif execution_order == "tests-per-variant":
-            for index, (runnable, variant) in enumerate(((test, variant)
-                                                         for variant in test_suite.variants.itertests()
-                                                         for test in test_suite.tests),
-                                                        start=1):
-                runtime_tasks.extend(Runner._create_runtime_tasks_for_test(
-                    test_suite,
-                    runnable,
-                    no_digits,
-                    index,
-                    variant))
+            test_variant = [(test, variant)
+                            for variant in test_suite.variants.itertests()
+                            for test in test_suite.tests]
+
+        # decide if a copy of the runnable is needed, in case of more
+        # variants than tests
+        copy_runnable = len(test_variant) > len(test_suite.tests)
+        # create runtime tasks
+        for index, (runnable, variant) in enumerate(test_variant, start=1):
+            if copy_runnable:
+                runnable = deepcopy(runnable)
+            runtime_tasks.extend(self._create_runtime_tasks_for_test(
+                test_suite,
+                runnable,
+                no_digits,
+                index,
+                variant,
+                job_id))
         return runtime_tasks
 
-    def _start_status_server(self, status_server_listen):
+    def _determine_status_server_uri(self, test_suite, job):
+        if test_suite.config.get('nrunner.status_server_auto'):
+            # no UNIX domain sockets on Windows
+            if platform.system() != 'Windows':
+                return os.path.join(job.logdir, '.status_server.sock')
+        return test_suite.config.get('nrunner.status_server_listen')
+
+    def _create_status_server(self, test_suite, job):
+        listen = self._determine_status_server_uri(test_suite, job)
         # pylint: disable=W0201
-        self.status_repo = StatusRepo()
+        self.status_repo = StatusRepo(job.unique_id)
         # pylint: disable=W0201
-        self.status_server = StatusServer(status_server_listen,
+        self.status_server = StatusServer(listen,
                                           self.status_repo)
-        asyncio.ensure_future(self.status_server.serve_forever())
 
     async def _update_status(self, job):
         tasks_by_id = {str(runtime_task.task.identifier): runtime_task.task
@@ -271,18 +308,31 @@ class Runner(RunnerInterface):
             task = tasks_by_id.get(task_id)
             message_handler.process_message(message, task, job)
 
+    @staticmethod
+    def _abort_if_missing_runners(runnables):
+        if runnables:
+            missing_kinds = set([runnable.kind for runnable in runnables])
+            msg = ("Could not find runners for runnable(s) of kind(s): %s"
+                   % ", ".join(missing_kinds))
+            raise JobError(msg)
+
     def run_suite(self, job, test_suite):
         summary = set()
 
-        test_suite.tests, _ = nrunner.check_runnables_runner_requirements(
+        test_suite.tests, missing_requirements = nrunner.check_runnables_runner_requirements(
             test_suite.tests)
+        self._abort_if_missing_runners(missing_requirements)
+
         job.result.tests_total = test_suite.variants.get_number_of_tests(test_suite.tests)
 
-        listen = test_suite.config.get('nrunner.status_server_listen')
-        self._start_status_server(listen)
+        self._create_status_server(test_suite, job)
 
         # pylint: disable=W0201
-        self.runtime_tasks = self._get_all_runtime_tasks(test_suite)
+        self.runtime_tasks = self._get_all_runtime_tasks(test_suite, job.unique_id)
+
+        # Start the status server
+        asyncio.ensure_future(self.status_server.serve_forever())
+
         if test_suite.config.get('nrunner.shuffle'):
             random.shuffle(self.runtime_tasks)
         test_ids = [rt.task.identifier for rt in self.runtime_tasks
@@ -303,7 +353,9 @@ class Runner(RunnerInterface):
         try:
             loop.run_until_complete(asyncio.wait_for(asyncio.gather(*workers),
                                                      job.timeout or None))
-        except (KeyboardInterrupt, asyncio.TimeoutError):
+        except (KeyboardInterrupt, asyncio.TimeoutError, TestFailFast) as ex:
+            LOG_JOB.info(str(ex))
+            job.interrupted_reason = str(ex)
             summary.add("INTERRUPTED")
 
         # Wait until all messages may have been processed by the
