@@ -19,7 +19,11 @@ AVOCADO_QUOTED = "', '".join(shlex.split(AVOCADO))
 PERL_TAP_PARSER_SNIPPET = """#!/bin/env perl
 use TAP::Parser;
 
-my $parser = TAP::Parser->new( { exec => ['%s', 'run', 'passtest.py', 'errortest.py', 'warntest.py', '--tap', '-', '--disable-sysinfo', '--job-results-dir', '%%s'] } );
+my $parser = TAP::Parser->new( { exec => ['%s', 'run', 'examples/tests/passtest.py',
+                                          'examples/tests/errortest.py',
+                                          'examples/tests/warntest.py',
+                                          '--tap', '-', '--disable-sysinfo',
+                                          '--job-results-dir', '%%s'] } );
 
 while ( my $result = $parser->next ) {
         $result->is_unknown && die "Unknown line \\"" . $result->as_string . "\\" in the TAP output!\n";
@@ -33,7 +37,12 @@ $parser->plan eq '1..3' || die "Plan does not match what was expected!\n";
 PERL_TAP_PARSER_FAILFAST_SNIPPET = """#!/bin/env perl
 use TAP::Parser;
 
-my $parser = TAP::Parser->new( { exec => ['%s', 'run', 'failtest.py', 'errortest.py', 'warntest.py', '--tap', '-', '--failfast', '--disable-sysinfo', '--job-results-dir', '%%s'] } );
+my $parser = TAP::Parser->new( { exec => ['%s', 'run', 'examples/tests/failtest.py',
+                                          'examples/tests/errortest.py',
+                                          'examples/tests/warntest.py',
+                                          '--tap', '-', '--failfast',
+                                          '--disable-sysinfo', '--job-results-dir',
+                                          '%%s'] } );
 
 while ( my $result = $parser->next ) {
         $result->is_unknown && die "Unknown line \\"" . $result->as_string . "\\" in the TAP output!\n";
@@ -155,6 +164,7 @@ class PassTest(Test):
 
 if __name__ == '__main__':
     config = {'run.references': [__file__],
+              'run.test_runner': 'nrunner',
               'core.show': ['app']}
     suite = TestSuite.from_config(config)
     with Job(config, [suite]) as j:
@@ -168,36 +178,21 @@ from avocado.core.job import Job
 from avocado.core.task.runtime import RuntimeTask
 from avocado.core.test_id import TestID
 from avocado.plugins import runner_nrunner
-from avocado.utils.network.ports import find_free_port
 
 
 class RunnerNRunnerWithFixedTasks(runner_nrunner.Runner):
-    @staticmethod
-    def _get_all_runtime_tasks(test_suite):
-        runtime_tasks = []
-        no_digits = len(str(len(test_suite)))
-        status_uris = [test_suite.config.get('nrunner.status_server_uri')]
-        for index, runnable in enumerate(test_suite.tests, start=1):
-            prefix = index
-            test_id = TestID(prefix, runnable.uri, None, no_digits)
-            if '/bin/true' in runnable.uri:
-                task = nrunner.Task(
-                    runnable, test_id, status_uris,
-                    nrunner.RUNNERS_REGISTRY_PYTHON_CLASS)
-            else:
-                task = nrunner.Task(
-                    runnable, test_id, status_uris,
-                    nrunner.RUNNERS_REGISTRY_PYTHON_CLASS,
-                    'non-test')
-            runtime_tasks.append(RuntimeTask(task))
-        return runtime_tasks
+    def _create_runtime_tasks_for_test(self, test_suite, runnable, no_digits,
+                                       index, variant, job_id):
+        result = super(RunnerNRunnerWithFixedTasks, self)._create_runtime_tasks_for_test(
+            test_suite, runnable, no_digits, index, variant, job_id)
+        for rt_task in result:
+            if rt_task.task.runnable.uri != '/bin/true':
+                rt_task.task.category = 'non-test'
+        return result
 
 
 if __name__ == '__main__':
-    status_server = '127.0.0.1:%u' % find_free_port()
     config = {'run.test_runner': 'nrunner',
-              'nrunner.status_server_listen': status_server,
-              'nrunner.status_server_uri': status_server,
               'run.references': ['/bin/true', '/bin/false']}
     job = Job.from_config(config)
     job.setup()
@@ -224,7 +219,7 @@ class OutputTest(TestCaseTmpDir):
                      "C compiler is required by the underlying doublefree.py test")
     def test_output_doublefree(self):
         cmd_line = ('%s run --job-results-dir %s --disable-sysinfo '
-                    'doublefree.py' % (AVOCADO, self.tmpdir.name))
+                    'examples/tests/doublefree.py' % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
         output = result.stdout + result.stderr
@@ -258,6 +253,7 @@ class OutputTest(TestCaseTmpDir):
                              OUTPUT_TEST_CONTENT)
         test.save()
         result = process.run("%s run --job-results-dir %s --disable-sysinfo "
+                             "--test-runner=runner "
                              "--json - -- %s" % (AVOCADO, self.tmpdir.name, test))
         res = json.loads(result.stdout_text)
         joblog = res["debuglog"]
@@ -284,6 +280,7 @@ class OutputTest(TestCaseTmpDir):
         # But this change will come later
         result = process.run("%s run --job-results-dir %s --disable-sysinfo "
                              "--output-check-record=combined "
+                             "--test-runner=runner "
                              "--json - -- %s" % (AVOCADO, self.tmpdir.name, test))
         res = json.loads(result.stdout_text)
         testdir = res["tests"][0]["logdir"]
@@ -308,6 +305,7 @@ class OutputTest(TestCaseTmpDir):
                            OUTPUT_MODE_NONE_CONTENT,
                            script.READ_ONLY_MODE) as test:
             command = ("%s run --job-results-dir %s --disable-sysinfo "
+                       "--test-runner=runner "
                        "--json - --output-check-record none -- %s") % (AVOCADO,
                                                                        self.tmpdir.name,
                                                                        test.path)
@@ -332,6 +330,7 @@ class OutputTest(TestCaseTmpDir):
                            OUTPUT_CHECK_ON_OFF_CONTENT,
                            script.READ_ONLY_MODE) as test:
             command = ("%s run --job-results-dir %s --disable-sysinfo "
+                       "--test-runner=runner "
                        "--json - -- %s") % (AVOCADO, self.tmpdir.name, test.path)
             result = process.run(command)
             res = json.loads(result.stdout_text)
@@ -354,10 +353,10 @@ class OutputTest(TestCaseTmpDir):
         """
         with script.Script(os.path.join(self.tmpdir.name, "test_show.py"),
                            OUTPUT_SHOW_TEST, script.READ_ONLY_MODE) as test:
-            cmd = "%s run %s" % (AVOCADO, test.path)
+            cmd = "%s run --disable-sysinfo -- %s" % (AVOCADO, test.path)
             result = process.run(cmd)
-            expected_job_id_number = 2
-            expected_bin_true_number = 1
+            expected_job_id_number = 1
+            expected_bin_true_number = 0
             job_id_number = result.stdout_text.count('JOB ID')
             bin_true_number = result.stdout_text.count('/bin/true')
             self.assertEqual(expected_job_id_number, job_id_number)
@@ -408,7 +407,8 @@ class OutputPluginTest(TestCaseTmpDir):
 
     def test_output_incompatible_setup(self):
         cmd_line = ('%s run --job-results-dir %s --disable-sysinfo '
-                    '--xunit - --json - passtest.py' % (AVOCADO, self.tmpdir.name))
+                    '--xunit - --json - examples/tests/passtest.py'
+                    % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_FAIL
         self.assertEqual(result.exit_status, expected_rc,
@@ -424,7 +424,7 @@ class OutputPluginTest(TestCaseTmpDir):
     def test_output_compatible_setup(self):
         tmpfile = tempfile.mktemp(dir=self.tmpdir.name)
         cmd_line = ('%s run --job-results-dir %s --disable-sysinfo '
-                    '--journal --xunit %s --json - passtest.py' %
+                    '--journal --xunit %s --json - examples/tests/passtest.py' %
                     (AVOCADO, self.tmpdir.name, tmpfile))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -438,7 +438,8 @@ class OutputPluginTest(TestCaseTmpDir):
     def test_output_compatible_setup_2(self):
         tmpfile = tempfile.mktemp(dir=self.tmpdir.name)
         cmd_line = ('%s run --job-results-dir %s --disable-sysinfo '
-                    '--xunit - --json %s --tap-include-logs passtest.py'
+                    '--xunit - --json %s --tap-include-logs '
+                    'examples/tests/passtest.py'
                     % (AVOCADO, self.tmpdir.name, tmpfile))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -458,7 +459,8 @@ class OutputPluginTest(TestCaseTmpDir):
         # Verify --show=none can be supplied as app argument
         cmd_line = ('%s --show=none run --job-results-dir %s '
                     '--disable-sysinfo --xunit %s --json %s --tap-include-logs '
-                    'passtest.py' % (AVOCADO, self.tmpdir.name, tmpfile, tmpfile2))
+                    'examples/tests/passtest.py' % (AVOCADO, self.tmpdir.name,
+                                                    tmpfile, tmpfile2))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
         self.assertEqual(result.exit_status, expected_rc,
@@ -477,6 +479,7 @@ class OutputPluginTest(TestCaseTmpDir):
         cmd_line = ("%s run --external-runner /bin/ls "
                     "'NON_EXISTING_FILE_WITH_NONPRINTABLE_CHARS_IN_HERE\x1b' "
                     "--job-results-dir %s --disable-sysinfo --tap-include-logs"
+                    " --test-runner=runner"
                     % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
         output = result.stdout_text + result.stderr_text
@@ -495,7 +498,7 @@ class OutputPluginTest(TestCaseTmpDir):
 
     def test_show_test(self):
         cmd_line = ('%s --show=test run --job-results-dir %s --disable-sysinfo '
-                    'passtest.py' % (AVOCADO, self.tmpdir.name))
+                    'examples/tests/passtest.py' % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
         self.assertEqual(result.exit_status, expected_rc,
@@ -511,7 +514,7 @@ class OutputPluginTest(TestCaseTmpDir):
     def test_silent_trumps_test(self):
         # Also verify --show=none can be supplied as run option
         cmd_line = ('%s --show=test --show=none run --job-results-dir %s '
-                    '--disable-sysinfo passtest.py'
+                    '--disable-sysinfo examples/tests/passtest.py'
                     % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -527,7 +530,8 @@ class OutputPluginTest(TestCaseTmpDir):
                    % os.path.relpath(self.tmpdir.name, "."))
         script.Script(config, content).save()
         cmd_line = ('%s --config %s --show all run '
-                    '--job-results-dir %s --disable-sysinfo whiteboard.py '
+                    '--job-results-dir %s --disable-sysinfo '
+                    'examples/tests/whiteboard.py '
                     '--json %s' % (AVOCADO, config, self.tmpdir.name, tmpfile))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -545,7 +549,8 @@ class OutputPluginTest(TestCaseTmpDir):
     def test_gendata(self):
         tmpfile = tempfile.mktemp(dir=self.tmpdir.name)
         cmd_line = ("%s run --job-results-dir %s "
-                    "--disable-sysinfo gendata.py --json %s" %
+                    "--test-runner=runner "
+                    "--disable-sysinfo examples/tests/gendata.py --json %s" %
                     (AVOCADO, self.tmpdir.name, tmpfile))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -569,7 +574,7 @@ class OutputPluginTest(TestCaseTmpDir):
     def test_redirect_output(self):
         redirected_output_path = tempfile.mktemp(dir=self.tmpdir.name)
         cmd_line = ('%s run --job-results-dir %s '
-                    '--disable-sysinfo passtest.py > %s'
+                    '--disable-sysinfo examples/tests/passtest.py > %s'
                     % (AVOCADO, self.tmpdir.name, redirected_output_path))
         result = process.run(cmd_line, ignore_status=True, shell=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -604,8 +609,11 @@ class OutputPluginTest(TestCaseTmpDir):
             process.run("perl %s" % perl_script)
 
     def test_tap_totaltests(self):
-        cmd_line = ("%s run passtest.py passtest.py passtest.py passtest.py "
-                    "--job-results-dir %s "
+        cmd_line = ("%s run examples/tests/passtest.py "
+                    "examples/tests/passtest.py "
+                    "examples/tests/passtest.py "
+                    "examples/tests/passtest.py "
+                    "--job-results-dir %s --disable-sysinfo "
                     "--tap -" % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line)
         expr = b'1..4'
