@@ -152,7 +152,7 @@ class RunnableFromCommandLineArgs(unittest.TestCase):
 class RunnableToRecipe(unittest.TestCase):
 
     def setUp(self):
-        prefix = temp_dir_prefix(__name__, self, 'setUp')
+        prefix = temp_dir_prefix(self)
         self.tmpdir = tempfile.TemporaryDirectory(prefix=prefix)
 
     def test_runnable_to_recipe_noop(self):
@@ -250,75 +250,25 @@ class Runner(unittest.TestCase):
         self.assertEqual(last_result['returncode'], 1)
         self.assertIn('time', last_result)
 
-    def test_runner_python_unittest_ok(self):
-        runnable = nrunner.Runnable('python-unittest', 'unittest.TestCase')
-        runner_klass = runnable.pick_runner_class()
-        runner = runner_klass(runnable)
-        results = [status for status in runner.run()]
-        output1 = (b'----------------------------------------------------------'
-                   b'------------\nRan 0 tests in ')
-        output2 = b's\n\nOK\n'
-        output = results[-2]
-        result = results[-1]
-        self.assertEqual(result['status'], 'finished')
-        self.assertEqual(result['result'], 'pass')
-        self.assertTrue(output['log'].startswith(output1))
-        self.assertTrue(output['log'].endswith(output2))
-
-    def test_runner_python_unittest_fail(self):
-        runnable = nrunner.Runnable('python-unittest', 'unittest.TestCase.fail')
-        runner_klass = runnable.pick_runner_class()
-        runner = runner_klass(runnable)
-        results = [status for status in runner.run()]
-        output1 = (b'============================================================='
-                   b'=========\nFAIL: fail (unittest.case.TestCase)'
-                   b'\nFail immediately, with the given message.')
-        output2 = b'\n\nFAILED (failures=1)\n'
-        output = results[-2]
-        result = results[-1]
-        self.assertEqual(result['status'], 'finished')
-        self.assertEqual(result['result'], 'fail')
-        self.assertTrue(output['log'].startswith(output1))
-        self.assertTrue(output['log'].endswith(output2))
-
-    def test_runner_python_unittest_skip(self):
-        runnable = nrunner.Runnable(
-            'python-unittest',
-            'selftests.unit.test_test.TestClassTestUnit.DummyTest.skip')
-        runner_klass = runnable.pick_runner_class()
-        runner = runner_klass(runnable)
-        results = [status for status in runner.run()]
-        output1 = (b'----------------------------------------------------------'
-                   b'------------\nRan 1 test in ')
-        output2 = b's\n\nOK (skipped=1)\n'
-        output = results[-2]
-        result = results[-1]
-        self.assertEqual(result['status'], 'finished')
-        self.assertEqual(result['result'], 'skip')
-        self.assertTrue(output['log'].startswith(output1))
-        self.assertTrue(output['log'].endswith(output2))
-
     def test_runner_python_unittest_error(self):
         runnable = nrunner.Runnable('python-unittest', 'error')
         runner_klass = runnable.pick_runner_class()
         runner = runner_klass(runnable)
         results = [status for status in runner.run()]
-        output1 = (b'============================================================='
-                   b'=========\nERROR: error')
-        output2 = b'\n\nFAILED (errors=1)\n'
-        output = results[-2]
+        output = ("Invalid URI: could not be converted to an unittest "
+                  "dotted name.")
         result = results[-1]
         self.assertEqual(result['status'], 'finished')
         self.assertEqual(result['result'], 'error')
-        self.assertTrue(output['log'].startswith(output1))
-        self.assertTrue(output['log'].endswith(output2))
+        self.assertEqual(result['output'], output)
 
     def test_runner_python_unittest_empty_uri_error(self):
         runnable = nrunner.Runnable('python-unittest', '')
         runner_klass = runnable.pick_runner_class()
         runner = runner_klass(runnable)
         results = [status for status in runner.run()]
-        output = 'uri is required but was not given'
+        output = ("Invalid URI: could not be converted to an unittest "
+                  "dotted name.")
         result = results[-1]
         self.assertEqual(result['status'], 'finished')
         self.assertEqual(result['result'], 'error')
@@ -328,7 +278,7 @@ class Runner(unittest.TestCase):
 class RunnerTmp(unittest.TestCase):
 
     def setUp(self):
-        prefix = temp_dir_prefix(__name__, self, 'setUp')
+        prefix = temp_dir_prefix(self)
         self.tmpdir = tempfile.TemporaryDirectory(prefix=prefix)
 
     @skipUnlessPathExists('/bin/sh')
